<!DOCTYPE html>
<html lang="en">
   <head>
      <meta charset="UTF-8">
      <title>{{ title }}</title>
      <link
         rel="stylesheet"
         href="https://unpkg.com/purecss@2.0.6/build/pure-min.css"
         integrity="sha384-Uu6IeWbM+gzNVXJcM9XV3SohHtmWE+3VGi496jvgX1jyvDTXfdK+rfZc8C1Aehk5"
         crossorigin="anonymous">
      <link href="/prompter.css" rel="stylesheet">
   </head>
   <body>
      <div class="pure-g">
         <div class="pure-u-1-2">
            <div class="script-list">
                {% for element in elements %}
                  <p><a href="{{ element.link }}">{{ element.name }}</a></p>
                {% endfor %}
                <p><a href="/remote.html">Control</a></p>
            </div>
         </div>
         <div id="mirror" class="pure-u-1-2 mirrored">
            <div class="script-list">
                {% for element in elements %}
                  <p><a href="{{ element.link }}">{{ element.name }}</a></p>
                {% endfor %}
                <p><a href="/remote.html">Control</a></p>
            </div>
         </div>
      </div>
   </body>
</html>