<html>
    <head>
        <meta charset="UTF-8">
        <link href="/prompter.css" rel="stylesheet">
        <script src="https://code.jquery.com/jquery-3.6.0.slim.min.js"
                integrity="sha256-u7e5khyithlIdTpu22PHhENmPcRdFiHRjhAuHcs05RI="
                crossorigin="anonymous"></script>
        <script src="https://polyfill.io/v3/polyfill.min.js?features=es6"></script>
        <script id="MathJax-script" async src="https://cdn.jsdelivr.net/npm/mathjax@3/es5/tex-mml-chtml.js"></script>
        <title>{{ title }}</title>
    </head>
    <body>
    <div id="content" class="mirrored">
    {% for element in elements %}
        {{ element|safe }}<br />
    {% endfor %}
    </div>
    <div id="debug"></div>
    <script src="/prompter.js"></script>
    </body>
</html>