@import url('https://fonts.googleapis.com/css2?family=Noto+Sans+JP:wght@100;300;400;500;700;900&display=swap');
@import url('https://fonts.googleapis.com/css2?family=Lato:ital@1&display=swap');

body {
    background-color: black;
    color: white;
}

br {
    display: block;
    margin-top: 40px;
    content: "";
}

#content {
    font-size: 50px;
    padding: 100px 50px;
    font-family: 'Noto Sans JP', sans-serif;
}

#debug {
  background-color: black;
  font-size: 20px;
  display: block;
  padding: 3px;
  font-family: 'Lato', sans-serif;
  position: fixed;
  top:0; left:0;
  width: 100%;
}

.script-list {
    box-sizing: border-box;
    padding: 30px;
    font-size: 1.5em;
}

.mirrored {
    -moz-transform: scale(-1, 1);
    -webkit-transform: scale(-1, 1);
    -o-transform: scale(-1, 1);
    -ms-transform: scale(-1, 1);
    transform: scale(-1, 1);
}

a, a:visited {
    color: white;
    font-family: 'Lato', sans-serif;
}

h1, h2, h3 {
    margin: 0;
}
